@@ -36,9 +36,9 @@
 #include <goffice/graph/gog-error-bar.h>
 #include <goffice/graph/gog-series-lines.h>
 #include <goffice/data/go-data-simple.h>
+#include <goffice/math/go-math.h>
 #include <goffice/utils/go-format.h>
 #include <goffice/utils/go-font.h>
-#include <goffice/utils/go-math.h>
 #include <goffice/app/go-plugin-service.h>
 #include <goffice/component/go-component-factory.h>
 #include <gsf/gsf-utils.h>
@@ -82,11 +82,14 @@ libgoffice_init (void)
 
 #ifdef G_OS_WIN32
 	{
-	gchar *dir = g_win32_get_package_installation_directory (NULL, "libgoffice-0-3.dll");
+#define S(s)	#s
+	gchar *dir = g_win32_get_package_installation_directory (NULL, (char *)
+		"libgoffice-" S(GO_VERSION_EPOCH) "-" S(GO_VERSION_MAJOR) ".dll");
+#undef S
 	libgoffice_data_dir = g_build_filename (dir,
 		"share", "goffice", GOFFICE_VERSION, NULL);
 	libgoffice_icon_dir = g_build_filename (dir,
-		"share", "pixmaps", "goffice", NULL);
+		"share", "pixmaps", "goffice", GOFFICE_VERSION, NULL);
 	libgoffice_locale_dir = g_build_filename (dir,
 		"share", "locale", NULL);
 	libgoffice_lib_dir = g_build_filename (dir,
@@ -137,9 +140,10 @@ libgoffice_shutdown (void)
 	go_currency_date_format_shutdown ();
 	go_number_format_shutdown ();
 #ifdef G_OS_WIN32
-	g_free (libgoffice_data_dir);
-	g_free (libgoffice_icon_dir);
-	g_free (libgoffice_locale_dir);
-	g_free (libgoffice_lib_dir);
+	/* const_cast, we created these above */
+	g_free ((char *)libgoffice_data_dir);
+	g_free ((char *)libgoffice_icon_dir);
+	g_free ((char *)libgoffice_locale_dir);
+	g_free ((char *)libgoffice_lib_dir);
 #endif
 }
