@@ -47,6 +47,8 @@ typedef GtkToolItemClass GOToolComboColorClass;
 #define IS_GO_TOOL_COMBO_COLOR(o)	(G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TOOL_COMBO_COLOR_TYPE))
 
 static GType go_tool_combo_color_get_type (void);
+
+#ifndef HAVE_GTK_TOOL_ITEM_SET_TOOLTIP_TEXT
 static gboolean
 go_tool_combo_color_set_tooltip (GtkToolItem *tool_item, GtkTooltips *tooltips,
 				 char const *tip_text,
@@ -57,10 +59,14 @@ go_tool_combo_color_set_tooltip (GtkToolItem *tool_item, GtkTooltips *tooltips,
 				  tip_text, tip_private);
 	return TRUE;
 }
+#endif
+
 static void
 go_tool_combo_color_class_init (GtkToolItemClass *tool_item_class)
 {
+#ifndef HAVE_GTK_TOOL_ITEM_SET_TOOLTIP_TEXT
 	tool_item_class->set_tooltip = go_tool_combo_color_set_tooltip;
+#endif
 }
 
 static GdkPixbuf *
@@ -279,7 +285,7 @@ go_action_combo_color_new (char const  *action_name,
 void
 go_action_combo_color_set_group (GOActionComboColor *action, gpointer group_key)
 {
-#warning TODO
+/* FIXME FIXME FIXME TODO */
 }
 
 GOColor
