@@ -48,6 +48,13 @@ typedef enum {
 	GO_DOTDOT_LEAVE         /* Leave alone.  */
 } GODotDot;
 
+#ifndef R_OK
+#  define F_OK 0
+#  define X_OK 1
+#  define W_OK 2
+#  define R_OK 4
+#endif
+
 char *go_filename_simplify (const char *filename, GODotDot dotdot, gboolean make_absolute);
 char *go_url_simplify (const char *uri);
 
@@ -77,6 +84,8 @@ time_t go_file_get_date_accessed (char const *uri);
 time_t go_file_get_date_modified (char const *uri);
 time_t go_file_get_date_changed  (char const *uri);
 
+gint	 go_file_access (char const *uri, gint mode);
+
 gchar	*go_url_decode		(gchar const *text);
 gchar	*go_url_encode		(gchar const *text, int type);
 GError	*go_url_show		(gchar const *url);
